//////////////////////////////////////////////////////////////////
// PolyDraw.cpp
// Various drawing functions
#include "stdafx.h"
#include "polydraw.h"
#include "HyperPlayPenDlg.h"


#define OBJ_RECTANGLE       0
#define OBJ_ELLIPSE         1
#define OBJ_ROUNDRECT       2
#define OBJ_CHORD           3
#define OBJ_PIE             4

DWORD FAR lRandom(VOID)
{
    static DWORD glSeed = (DWORD)-365387184;

    glSeed *= 69069;
    return(++glSeed);
}

void DrawCopyright(HWND hWnd, HDC hDC)
{
   CFont vFont;
   vFont.CreatePointFont(140, "Arial");

   HFONT hOldFont;
   if(hOldFont = (HFONT)SelectObject(hDC, vFont))
   {
      CString sText = "Hyper PlayPen -- A SteamingCoffee.com Production\n";
      sText += "Press CTRL+ALT+F4 to turn sound " + CString(g_bSoundOn ? "off" : "on") + ".\n";
      sText += "Press CTRL+ALT+F8 to exit.";

      SIZE vFontSize;
      GetTextExtentPoint(hDC, sText, strlen(sText), &vFontSize);

      RECT rect;
      GetWindowRect(hWnd, &rect);

      CRect vTextRect;
      if(rect.top < 0)
         vTextRect.top = -rect.top;
      else
         vTextRect.top = 0;

      int iLineCount = sText.Replace("\n", "\n")+1;
      vTextRect.bottom = vTextRect.top + vFontSize.cy * iLineCount;
      vTextRect.left = rect.left;
      vTextRect.right = rect.right;

      SetTextColor(hDC, RGB(lRandom() % 255,lRandom() % 255,lRandom() % 255));
      SetBkColor(hDC, 0);
      SetBkMode(hDC, OPAQUE);

      DrawText(hDC, sText, strlen(sText), &vTextRect, DT_CENTER | DT_VCENTER);

      DeleteObject(SelectObject(hDC, hOldFont));
   }
}

void DrawRandPoly(HWND hWnd)
{
   RECT      rect;
   HDC       hDC;
   int       x1,y1,x2,y2,x3,y3,x4,y4,r,g,b,nObject;
   HBRUSH    hBrush;

   if(hWnd)
   {
      if(hDC = GetDC(hWnd))
      {
         GetClientRect(hWnd,&rect);

         // avoid divide by zero errors when the window is small.
         if ( rect.right== 0) rect.right++;
         if ( rect.bottom== 0) rect.bottom++;

         r = lRandom() % 255;
         g = lRandom() % 255;
         b = lRandom() % 255;

         if(hBrush = (HBRUSH)SelectObject(hDC, CreateSolidBrush(RGB(r,g,b))))
         {
            x1 = lRandom() % rect.right;
            y1 = lRandom() % rect.bottom;
            x2 = lRandom() % rect.right;
            y2 = lRandom() % rect.bottom;
            x3 = lRandom() % rect.right;
            y3 = lRandom() % rect.bottom;
            x4 = lRandom() % rect.right;
            y4 = lRandom() % rect.bottom;

            nObject = lRandom() % 5;

            switch(nObject)
            {
            default:
            case OBJ_RECTANGLE:
               Rectangle(hDC,x1,y1,x2,y2);
               break;

            case OBJ_ELLIPSE:
               Ellipse(hDC,x1,y1,x2,y2);
               break;

            case OBJ_ROUNDRECT:
               RoundRect(hDC,x1,y1,x2,y2,x3,y3);
               break;

            case OBJ_CHORD:
               Chord(hDC,x1,y1,x2,y2,x3,y3,x4,y4);
               break;

            case OBJ_PIE:
               Pie(hDC,x1,y1,x2,y2,x3,y3,x4,y4);
               break;

            }

            DeleteObject(SelectObject(hDC,hBrush));
         }

         DrawCopyright(hWnd, hDC);

         ReleaseDC(hWnd,hDC);
      }
   }
   return;
}

// clears the screen by drawing a black rectangle the size of the client rect
void ClearScreen(HWND hWnd)
{
    HDC hDC = GetDC(hWnd);
    if (hDC)
    {
        HBRUSH hBlack = (HBRUSH)SelectObject(hDC, CreateSolidBrush(RGB(0, 0, 0)));
        RECT rect;
        GetClientRect(hWnd, &rect);

        Rectangle(hDC, rect.left, rect.top, rect.right, rect.bottom);
        DeleteObject(SelectObject(hDC, hBlack));

        DrawCopyright(hWnd, hDC);

        ReleaseDC(hWnd, hDC);
    }
    else
    {
        ASSERT(false); // couldn't get a DC for this window; weird
    }
}